@@ -1,4 +1,4 @@
-#include <catch.hpp>
+#include <catch2/catch.hpp>
 
 TEST_CASE("a", "[single]") {
     REQUIRE(1);
